/*
 * CVS identifier:
 *
 * $Id: ProgressionSpec.java,v 1.15 2001/02/19 11:17:25 grosbois Exp $
 *
 * Class:                   ProgressionSpec
 *
 * Description:             Specification of the progression(s) type(s) and
 *                          changes of progression.
 *
 * COPYRIGHT:
 * 
 * This software module was originally developed by Raphal Grosbois and
 * Diego Santa Cruz (Swiss Federal Institute of Technology-EPFL); Joel
 * Askelf (Ericsson Radio Systems AB); and Bertrand Berthelot, David
 * Bouchard, Flix Henry, Gerard Mozelle and Patrice Onno (Canon Research
 * Centre France S.A) in the course of development of the JPEG2000
 * standard as specified by ISO/IEC 15444 (JPEG 2000 Standard). This
 * software module is an implementation of a part of the JPEG 2000
 * Standard. Swiss Federal Institute of Technology-EPFL, Ericsson Radio
 * Systems AB and Canon Research Centre France S.A (collectively JJ2000
 * Partners) agree not to assert against ISO/IEC and users of the JPEG
 * 2000 Standard (Users) any of their rights under the copyright, not
 * including other intellectual property rights, for this software module
 * with respect to the usage by ISO/IEC and Users of this software module
 * or modifications thereof for use in hardware or software products
 * claiming conformance to the JPEG 2000 Standard. Those intending to use
 * this software module in hardware or software products are advised that
 * their use may infringe existing patents. The original developers of
 * this software module, JJ2000 Partners and ISO/IEC assume no liability
 * for use of this software module or modifications thereof. No license
 * or right to this software module is granted for non JPEG 2000 Standard
 * conforming products. JJ2000 Partners have full right to use this
 * software module for his/her own purpose, assign or donate this
 * software module to any third party and to inhibit third parties from
 * using this software module for non JPEG 2000 Standard conforming
 * products. This copyright notice must be included in all copies or
 * derivative works of this software module.
 * 
 * Copyright (c) 1999/2000 JJ2000 Partners.
 *  */
package jp2codec.entropy;

import jp2codec.*;

/**
 * This class extends ModuleSpec class for progression type(s) and progression
 * order changes holding purposes.
 * 
 * <P>It stores the progression type(s) used in the codestream. There can be
 * only one progression type or several ones if progression order changes are
 * used (POC markers).
 * */
public class ProgressionSpec extends ModuleSpec {

    /**
     * Creates a new ProgressionSpec object for the specified number of tiles
     * and components.
     *
     * @param nt The number of tiles
     *
     * @param nc The number of components
     *
     * @param type the type of the specification module i.e. tile specific,
     * component specific or both. The ProgressionSpec class should only be
     * used only with the type ModuleSpec.SPEC_TYPE_TILE.
     * */
    public ProgressionSpec(int nt, int nc, byte type) {
        super(nt, nc, type);
        if ( type !=  ModuleSpec.SPEC_TYPE_TILE ) {
            throw new Error("Illegal use of class ProgressionSpec !");
        }
    }

}