package jp2codec.imageio;

import jp2codec.imageio.*;

import javax.imageio.spi.ImageReaderSpi;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;
import java.io.IOException;
import java.util.Locale;

/**
 * Created by IntelliJ IDEA.
 * User: adm
 * Date: 2004-04-29
 * Time: 16:47:06
 * To change this template use File | Settings | File Templates.
 */
public class JP2ImageReaderSpi extends ImageReaderSpi{

    static final String vendorName = "Pawel Halasa";
    static final String version = "0.3";
    static final String readerClassName =
        "com.habib.imageio.JP2ImageReader";
    static final String[] names = {"JPEG 2000"};
    static final String[] suffixes = {"jp2", "jpc"};
    static final String[] MIMETypes = {
        "image/x-myformat" };
    static final String[] writerSpiNames = {
        "com.habib.imageio.JP2ImageWriterSpi" };

    // Metadata formats, more information below
    static final boolean supportsStandardStreamMetadataFormat = false;
    static final String nativeStreamMetadataFormatName = null;
    static final String nativeStreamMetadataFormatClassName = null;
    static final String[] extraStreamMetadataFormatNames = null;
    static final String[] extraStreamMetadataFormatClassNames = null;
    static final boolean supportsStandardImageMetadataFormat = false;
    static final String nativeImageMetadataFormatName =
        "com.habib.imageio.MyFormatMetadata_1.0";
    static final String nativeImageMetadataFormatClassName =
        "com.habib.imageio.MyFormatMetadata";
    static final String[] extraImageMetadataFormatNames = null;
    static final String[] extraImageMetadataFormatClassNames = null;

    public JP2ImageReaderSpi() {
        super(vendorName, version,
              names, suffixes, MIMETypes,
              readerClassName,
              STANDARD_INPUT_TYPE, // Accept ImageInputStreams
              writerSpiNames,
              supportsStandardStreamMetadataFormat,
              nativeStreamMetadataFormatName,
              nativeStreamMetadataFormatClassName,
              extraStreamMetadataFormatNames,
              extraStreamMetadataFormatClassNames,
              supportsStandardImageMetadataFormat,
              nativeImageMetadataFormatName,
              nativeStreamMetadataFormatClassName,
              extraImageMetadataFormatNames,
              extraImageMetadataFormatClassNames);
    }

    public String getDescription(Locale locale) {
        return "JP2 Decoder Plug-in";
    }

    public ImageReader createReaderInstance(Object extension) throws IOException {
        return new jp2codec.imageio.JP2ImageReader(this);
    }

    public boolean canDecodeInput(Object source) throws IOException {
        if (!(source instanceof ImageInputStream)) {
            return false;
        }

        ImageInputStream stream = (ImageInputStream)source;
        byte[] b = new byte[12];
        try {
            stream.mark();
            stream.readFully(b);
            stream.reset();
        } catch (IOException e) {
            return false;
        }

        // Cast unsigned character constants prior to comparison
        boolean r = (b[0] == (byte)0x00 && b[1] == (byte)0x00 &&
                b[2] == (byte)0x00 && b[3] == (byte)0x0c &&
                b[4] == (byte)0x6a && b[5] == (byte)0x50 &&
                b[6] == (byte)0x20 && b[7] == (byte)0x20 &&
                b[8] == (byte)0x0d && b[9] == (byte)0x0a &&
                b[10] == (byte)0x87 && b[11] == (byte)0x0a);
        return r;
    }

}
